.. _gui:

Graphical User Interface
========================

This section of the documentation is designed to be read by users of Antelop to help them use the graphical user interface.

.. toctree::
   :maxdepth: 1
   :titlesonly:

   installation
   usage
   search
   meta
   ephys
   behaviour
   vis
   analysis
   admin
